!=======================================================================
!
! ROUTINE    : nr_lubksb
!
! PURPOSE    : Solves set of n linear equations Ax = b.
!              Input is LU-decomp of matrix a coming from
!              nr_ludcmp.
!
! PARAMETERS : a     : LU-decomp of matrix a from nr_ludcmp
!              n     : dimensions
!              indx  : permutation vector from nr_ludcmp
!              b     : rhs-vector, will be overwritten with solution x
!
! COMMENTS   : a, n and indx are not modified.
!
!=======================================================================

subroutine lubksb (n, a, indx, b)

  implicit none

! subroutine arguments
  integer          :: n
  integer          :: indx(1:n)
  double precision :: b   (1:n)
  double precision :: a   (1:n,1:n)

! local variables
  integer          :: i, ii, ip, j
  double precision :: sumtmp

!-----------------------------------------------------------------

  ii = 0

  do i = 1, n
    ip = indx(i)
    sumtmp = b(ip)
    b(ip) = b(i)
    if (ii .ne. 0) then
      do j = ii, i-1
        sumtmp = sumtmp - a(i,j) * b(j)
      enddo
    else
      if (sumtmp .ne. 0.d0) ii = i
    endif
    b(i) = sumtmp
  enddo

  do i = n, 1, -1
    sumtmp = b(i)
    do j = i+1, n
      sumtmp = sumtmp - a(i,j) * b(j)
    enddo
    b(i) = sumtmp / a(i,i)
  enddo

  return
end

!=======================================================================

